@@ -23,8 +23,8 @@ import logging
 from collections import OrderedDict
 import time
 
-from gi.repository import Gtk
-from gi.repository import Pango
+from lib.gibindings import Gtk
+from lib.gibindings import Pango
 
 from lib import helpers
 from lib import fileutils
@@ -205,7 +205,7 @@ class _IOProgressUI:
 
         :param f: A list of filenames, or a single filename.
         :returns: A files_summary value for the constructor.
-        :rtype: unicode/str
+        :rtype: unicode|str
 
         """
         if isinstance(f, tuple) or isinstance(f, list):
@@ -979,7 +979,7 @@ class FileHandler (object):
         """Saves a document to one or more files
 
         :param filename: The base filename to save
-        :param gui.document.Document doc: Controller for the document to save
+        :param Document doc: Controller for the document to save
         :param bool export: True if exporting
         :param **options: Pass-through options
 
